@@ -53,6 +53,40 @@
     return(val)
   }
 }
+if(FALSE){
+"expint_En" <- function(n, x, give=FALSE, strict=TRUE){
+  jj <- process.args(n, x)
+  n.vec <- jj$arg1
+  x.vec <- jj$arg2
+  attr <- jj$attr
+
+  jj <- .C("expint_En_e",
+           as.integer(n.vec),
+           as.double(x.vec),
+           as.integer(length(x.vec)),
+           val=as.double(x.vec),
+           err=as.double(x.vec),
+           status=as.integer(0*x.vec),
+           PACKAGE="gsl"
+           )
+  val <- jj$val
+  err <- jj$err
+  status <- jj$status
+  attributes(val) <- attr
+  attributes(err) <- attr
+  attributes(status) <- attr
+
+  if(strict){
+    val <- strictify(val,status)
+  }
+  
+  if(give){
+    return(list(val=val,err=err,status=status))
+  } else {
+    return(val)
+  }
+}
+}
 
 "expint_Ei" <- function(x, give=FALSE, strict=TRUE){
   x.vec <- as.vector(x)
